#[repr(u8)]pub enum AhbPodfBusy {
AHB_PODF_BUSY_0 = 0,
AHB_PODF_BUSY_1 = 1,
}Variants
AHB_PODF_BUSY_0 = 0
divider is not busy and its value represents the actual division.
AHB_PODF_BUSY_1 = 1
divider is busy with handshake process with module. The value read in the divider represents the previous value of the division factor, and after the handshake the written value of the ahb_podf will be applied.
Implementations
Sourceimpl AhbPodfBusy
impl AhbPodfBusy