#[repr(u8)]pub enum ArmPodfBusy {
ARM_PODF_BUSY_0 = 0,
ARM_PODF_BUSY_1 = 1,
}Variants
ARM_PODF_BUSY_0 = 0
divider is not busy and its value represents the actual division.
ARM_PODF_BUSY_1 = 1
divider is busy with handshake process with module. The value read in the divider represents the previous value of the division factor, and after the handshake the written value of the arm_podf will be applied.
Implementations
Sourceimpl ArmPodfBusy
impl ArmPodfBusy