nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

IntMemClkLpm

Enum IntMemClkLpm 

#[repr(u8)]
pub enum IntMemClkLpm { INT_MEM_CLK_LPM_0 = 0, INT_MEM_CLK_LPM_1 = 1, }

Variants



INT_MEM_CLK_LPM_0 = 0

Disable the clock to the Arm platform memories when entering Low Power Mode



INT_MEM_CLK_LPM_1 = 1

Keep the clocks to the Arm platform memories enabled only if an interrupt is pending when entering Low Power Modes (WAIT and STOP without power gating)

Implementations

Source

impl IntMemClkLpm

pub const fn from_bits(val: u8) -> IntMemClkLpm

pub const fn to_bits(self) -> u8