#[repr(u8)]pub enum LrfPll {
LRF_PLL_0 = 0,
LRF_PLL_1 = 1,
}Variants
LRF_PLL_0 = 0
interrupt is not generated due to lock ready of all enabled and not bypaseed PLLs
LRF_PLL_1 = 1
interrupt generated due to lock ready of all enabled and not bypaseed PLLs
Implementations