nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Sbyos

Enum Sbyos 

#[repr(u8)]
pub enum Sbyos { SBYOS_0 = 0, SBYOS_1 = 1, }

Variants



SBYOS_0 = 0

On-chip oscillator will not be powered down, after next entrance to STOP mode. (CCM_REF_EN_B will remain asserted - ‘0’ and cosc_pwrdown will remain de asserted - ‘0’)



SBYOS_1 = 1

On-chip oscillator will be powered down, after next entrance to STOP mode. (CCM_REF_EN_B will be deasserted - ‘1’ and cosc_pwrdown will be asserted - ‘1’). When returning from STOP mode, external oscillator will be enabled again, on-chip oscillator will return to oscillator mode, and after oscnt count, CCM will continue with the exit from the STOP mode process.

Implementations

Source

impl Sbyos

pub const fn from_bits(val: u8) -> Sbyos

pub const fn to_bits(self) -> u8