#[repr(u8)]pub enum Vstby {
VSTBY_0 = 0,
VSTBY_1 = 1,
}Variants
VSTBY_0 = 0
Voltage will not be changed to standby voltage after next entrance to STOP mode. ( PMIC_STBY_REQ will remain negated - ‘0’)
VSTBY_1 = 1
Voltage will be requested to change to standby voltage after next entrance to stop mode. ( PMIC_STBY_REQ will be asserted - ‘1’).
Implementations